@@ -21,8 +21,8 @@ def lagrange(num: int) -> tuple:
 def calculate_numbers(left_border: int, right_border: int) -> list:
     """
     Function decompose number in interval [a, b)
-    :param left_border:
-    :param right_border:
+    :param left_border: First number in interval
+    :param right_border: Last number in interval (do not enter)
     :return:
     """
     list_of_numbers = []
